@@ -1,3 +1,3 @@
 from bevy.context import Context
-from bevy.inject import Bevy, Inject, Detect
+from bevy.inject import Bevy, Inject
 import bevy.providers as providers
